==> quanyi-center-api-1.0.32-20240424.091139-3-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/activity/RemoteActivityService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.activity;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.activity.ActivityDto;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityBatchUpdateCreatorParam;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityPageQueryParam;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 活动表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemoteActivityService {

    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 活动
     */
    ActivityDto selectById(Long id);

    /**
     * 根据主键批量查询
     *
     * @param ids 主键集合
     * @return 活动列表
     */
    List<ActivityDto> selectByIds(Set<Long> ids);

    /**
     * 根据主键批量查询可用的活动
     *
     * @param ids 主键集合
     * @return 活动列表
     */
    List<ActivityDto> selectAvailableByIds(Set<Long> ids);

    /**
     * 根据主键批量查询活动名称
     *
     * @param ids 主键集合
     * @return key：主键，value：活动名称
     */
    Map<Long, String> selectNameMapByIds(Set<Long> ids);

    /**
     * 创建活动
     *
     * @param activityDto
     * @return id
     */
    Long insert(ActivityDto activityDto);

    /**
     * 更新活动
     *
     * @param activityDto
     * @return id
     */
    int update(ActivityDto activityDto);

    /**
     * 更新活动
     *
     * @param id     活动id
     * @param status 状态
     * @return 影响行数
     */
    int updateStatus(Long id, int status);

    /**
     * 逻辑删除
     *
     * @param id 主键
     * @return 执行结果
     */
    int delete(Long id);

    /**
     * 分页查询
     *
     * @return 活动
     */
    List<ActivityDto> selectPage(ActivityPageQueryParam param);

    /**
     * count
     *
     * @return 数量
     */
    Integer count(ActivityPageQueryParam param);

    /**
     * 批量替换创建人
     *
     * @param param 参数
     * @return 影响行数
     */
    int batchUpdateCreator(ActivityBatchUpdateCreatorParam param);

    /**
     * 查询创建人数量
     *
     * @param createOperatorId 创建人ID
     * @return 数量
     */
    long selectCreatorCount(Long createOperatorId);

}

==> quanyi-center-api-1.2.18-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/activity/RemoteActivityService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.activity;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.activity.ActivityDto;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityBatchUpdateCreatorParam;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityPageQueryParam;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 活动表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemoteActivityService {

    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 活动
     */
    ActivityDto selectById(Long id);

    /**
     * 根据主键批量查询
     *
     * @param ids 主键集合
     * @return 活动列表
     */
    List<ActivityDto> selectByIds(Set<Long> ids);

    /**
     * 根据主键批量查询可用的活动
     *
     * @param ids 主键集合
     * @return 活动列表
     */
    List<ActivityDto> selectAvailableByIds(Set<Long> ids);

    /**
     * 根据主键批量查询活动名称
     *
     * @param ids 主键集合
     * @return key：主键，value：活动名称
     */
    Map<Long, String> selectNameMapByIds(Set<Long> ids);

    /**
     * 创建活动
     *
     * @param activityDto
     * @return id
     */
    Long insert(ActivityDto activityDto);

    /**
     * 更新活动
     *
     * @param activityDto
     * @return id
     */
    int update(ActivityDto activityDto);

    /**
     * update create operator
     *
     * @param id                 id
     * @param createOperatorId   create operator id
     * @param createOperatorName create operator name
     * @return int
     */
    int updateCreateOperator(Long id, Long createOperatorId, String createOperatorName);

    /**
     * 更新活动
     *
     * @param id     活动id
     * @param status 状态
     * @return 影响行数
     */
    int updateStatus(Long id, int status);

    /**
     * 逻辑删除
     *
     * @param id 主键
     * @return 执行结果
     */
    int delete(Long id);

    /**
     * 分页查询
     *
     * @return 活动
     */
    List<ActivityDto> selectPage(ActivityPageQueryParam param);

    /**
     * count
     *
     * @return 数量
     */
    Integer count(ActivityPageQueryParam param);

    /**
     * 批量替换创建人
     *
     * @param param 参数
     * @return 影响行数
     */
    int batchUpdateCreator(ActivityBatchUpdateCreatorParam param);

    /**
     * 查询创建人数量
     *
     * @param createOperatorId 创建人ID
     * @return 数量
     */
    long selectCreatorCount(Long createOperatorId);

}
